@@ -5,10 +5,9 @@ import asyncio
 from collections.abc import Sequence
 import logging
 import time
-from typing import ClassVar, Dict, Final, List, Optional, Tuple
+from typing import ClassVar, Final
 
 from pyplumio.const import (
-    ATTR_LOADED,
     ATTR_PASSWORD,
     ATTR_SENSORS,
     ATTR_STATE,
@@ -17,13 +16,13 @@ from pyplumio.const import (
     DeviceState,
     DeviceType,
     FrameType,
+    ProductType,
 )
 from pyplumio.devices import Addressable, Mixer, Thermostat
 from pyplumio.frames import DataFrameDescription, get_frame_handler, is_known_frame_type
 from pyplumio.helpers.factory import factory
 from pyplumio.helpers.filters import on_change
 from pyplumio.helpers.network_info import NetworkInfo
-from pyplumio.helpers.product_info import ProductType
 from pyplumio.helpers.schedule import Schedule, ScheduleDay
 from pyplumio.helpers.typing import DeviceDataType, ParameterDataType, VersionsInfoType
 from pyplumio.structures import StructureDecoder
@@ -68,7 +67,7 @@ ATTR_FUEL_BURNED: Final = "fuel_burned"
 
 MAX_TIME_SINCE_LAST_FUEL_DATA: Final = 300
 
-DATA_FRAME_TYPES: Tuple[DataFrameDescription, ...] = (
+DATA_FRAME_TYPES: tuple[DataFrameDescription, ...] = (
     DataFrameDescription(frame_type=FrameType.REQUEST_UID, provides=ATTR_PRODUCT),
     DataFrameDescription(
         frame_type=FrameType.REQUEST_DATA_SCHEMA, provides=ATTR_SCHEMA
@@ -98,6 +97,7 @@ class EcoMAX(Addressable):
 
     address: ClassVar[int] = DeviceType.ECOMAX
     _frame_versions: VersionsInfoType
+    _frame_types: tuple[DataFrameDescription, ...] = DATA_FRAME_TYPES
     _fuel_burned_timestamp: float = 0.0
 
     def __init__(self, queue: asyncio.Queue, network: NetworkInfo):
@@ -121,23 +121,6 @@ class EcoMAX(Addressable):
         self.subscribe(
             ATTR_THERMOSTAT_PARAMETERS_DECODER, self._decode_thermostat_parameters
         )
-        self.subscribe_once(ATTR_LOADED, self._request_data_frames)
-
-    async def _request_data_frames(self, loaded: bool) -> None:
-        """Request initial data frames."""
-        try:
-            await asyncio.gather(
-                *{
-                    self.create_task(
-                        self.make_request(
-                            description.provides, description.frame_type, timeout=3
-                        )
-                    )
-                    for description in DATA_FRAME_TYPES
-                }
-            )
-        except ValueError as e:
-            _LOGGER.error("Request failed: %s", e)
 
     async def _update_frame_versions(self, versions: VersionsInfoType) -> None:
         """Check versions and fetch outdated frames."""
@@ -153,7 +136,7 @@ class EcoMAX(Addressable):
 
     def _get_mixer(self, index: int, mixer_count: int) -> Mixer:
         """Get or create a new mixer object and add it to the device."""
-        mixers: Dict[int, Mixer] = self.data.setdefault(ATTR_MIXERS, {})
+        mixers: dict[int, Mixer] = self.data.setdefault(ATTR_MIXERS, {})
         try:
             mixer = mixers[index]
         except KeyError:
@@ -168,7 +151,7 @@ class EcoMAX(Addressable):
     def _get_thermostat(self, index: int, thermostat_count: int) -> Thermostat:
         """Get or create a new thermostat object and add it to the
         device."""
-        thermostats: Dict[int, Thermostat] = self.data.setdefault(ATTR_THERMOSTATS, {})
+        thermostats: dict[int, Thermostat] = self.data.setdefault(ATTR_THERMOSTATS, {})
         try:
             thermostat = thermostats[index]
         except KeyError:
@@ -188,7 +171,7 @@ class EcoMAX(Addressable):
         return True
 
     async def _add_ecomax_parameters(
-        self, parameters: Sequence[Tuple[int, ParameterDataType]]
+        self, parameters: Sequence[tuple[int, ParameterDataType]]
     ) -> bool:
         """Add ecomax parameters to the device data."""
         product = await self.get_value(ATTR_PRODUCT)
@@ -211,9 +194,9 @@ class EcoMAX(Addressable):
         return True
 
     async def _add_mixer_sensors(
-        self, sensors: Sequence[Tuple[int, DeviceDataType]]
+        self, sensors: Sequence[tuple[int, DeviceDataType]]
     ) -> bool:
-        """Set sensor values for the mixer."""
+        """set sensor values for the mixer."""
         for mixer_index, mixer_sensors in sensors:
             mixer = self._get_mixer(mixer_index, len(sensors))
             for name, value in mixer_sensors.items():
@@ -223,11 +206,10 @@ class EcoMAX(Addressable):
 
     async def _add_mixer_parameters(
         self,
-        parameters: Optional[
-            Sequence[Tuple[int, Sequence[Tuple[int, ParameterDataType]]]]
-        ],
+        parameters: Sequence[tuple[int, Sequence[tuple[int, ParameterDataType]]]]
+        | None,
     ) -> bool:
-        """Set mixer parameters."""
+        """set mixer parameters."""
         if parameters is None:
             return False
 
@@ -253,9 +235,9 @@ class EcoMAX(Addressable):
         return True
 
     async def _add_thermostat_sensors(
-        self, sensors: Sequence[Tuple[int, DeviceDataType]]
+        self, sensors: Sequence[tuple[int, DeviceDataType]]
     ) -> bool:
-        """Set sensor values for the thermostat."""
+        """set sensor values for the thermostat."""
         for thermostat_index, thermostat_sensors in sensors:
             thermostat = self._get_thermostat(thermostat_index, len(sensors))
             for name, value in thermostat_sensors.items():
@@ -265,11 +247,10 @@ class EcoMAX(Addressable):
 
     async def _add_thermostat_parameters(
         self,
-        parameters: Optional[
-            Sequence[Tuple[int, Sequence[Tuple[int, ParameterDataType]]]]
-        ],
+        parameters: Sequence[tuple[int, Sequence[tuple[int, ParameterDataType]]]]
+        | None,
     ) -> bool:
-        """Set thermostat parameters."""
+        """set thermostat parameters."""
         if parameters is None:
             return False
 
@@ -292,7 +273,7 @@ class EcoMAX(Addressable):
 
     async def _add_thermostat_profile_parameter(
         self, parameter: ParameterDataType
-    ) -> Optional[EcomaxParameter]:
+    ) -> EcomaxParameter | None:
         """Add thermostat profile parameter to the device instance."""
         if parameter is not None:
             return THERMOSTAT_PROFILE_PARAMETER.cls(
@@ -351,7 +332,7 @@ class EcoMAX(Addressable):
         return True
 
     async def _add_schedule_parameters(
-        self, parameters: Sequence[Tuple[int, ParameterDataType]]
+        self, parameters: Sequence[tuple[int, ParameterDataType]]
     ) -> bool:
         for index, value in parameters:
             description = SCHEDULE_PARAMETERS[index]
@@ -368,7 +349,7 @@ class EcoMAX(Addressable):
         return True
 
     async def _add_schedules(
-        self, schedules: List[Tuple[int, List[List[bool]]]]
+        self, schedules: list[tuple[int, list[list[bool]]]]
     ) -> DeviceDataType:
         """Add schedules."""
         return {
@@ -406,8 +387,7 @@ class EcoMAX(Addressable):
         """Cancel scheduled tasks for root and sub devices."""
         mixers = self.data.get(ATTR_MIXERS, {})
         thermostats = self.data.get(ATTR_THERMOSTATS, {})
-        subdevices = {**mixers, **thermostats}
-        for subdevice in subdevices.values():
+        for subdevice in (mixers | thermostats).values():
             await subdevice.shutdown()
 
         await super().shutdown()
