@@ -1,7 +1,7 @@
 """Contains alarms structure decoder."""
 from __future__ import annotations
 
-from typing import Final, Optional, Tuple
+from typing import Final
 
 from pyplumio.helpers.typing import DeviceDataType
 from pyplumio.structures import StructureDecoder, ensure_device_data
@@ -13,8 +13,8 @@ class PendingAlertsStructure(StructureDecoder):
     """Represents current alert data structure."""
 
     def decode(
-        self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
-    ) -> Tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
+    ) -> tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         alerts_number = message[offset]
         return ensure_device_data(data, {ATTR_PENDING_ALERTS: alerts_number}), (
